
test 

.. toctree::
   :maxdepth: 2
   :hidden:

   getting_started
   installation
   usage
   auto_tutorials/index
   auto_examples/index
   reference/index
   contributing_link
   release-history
   authors_link
   
